summaryrefslogtreecommitdiff
path: root/nuttx/fs/nfs/nfs_util.c
diff options
context:
space:
mode:
authorpatacongo <patacongo@42af7a65-404d-4744-a932-0658087f49c3>2012-04-20 23:15:41 +0000
committerpatacongo <patacongo@42af7a65-404d-4744-a932-0658087f49c3>2012-04-20 23:15:41 +0000
commita82c594ec12e6950e7bec190871361fcf95604e8 (patch)
treee9228b754258eb07f54b144a68a1e555c2512f20 /nuttx/fs/nfs/nfs_util.c
parentb96598f697397ed683d93f97467360e181ff1015 (diff)
downloadpx4-nuttx-a82c594ec12e6950e7bec190871361fcf95604e8.tar.gz
px4-nuttx-a82c594ec12e6950e7bec190871361fcf95604e8.tar.bz2
px4-nuttx-a82c594ec12e6950e7bec190871361fcf95604e8.zip
More NFS updates
git-svn-id: svn://svn.code.sf.net/p/nuttx/code/trunk@4638 42af7a65-404d-4744-a932-0658087f49c3
Diffstat (limited to 'nuttx/fs/nfs/nfs_util.c')
-rwxr-xr-xnuttx/fs/nfs/nfs_util.c16
1 files changed, 4 insertions, 12 deletions
diff --git a/nuttx/fs/nfs/nfs_util.c b/nuttx/fs/nfs/nfs_util.c
index 1e8805a92..6f5dd6991 100755
--- a/nuttx/fs/nfs/nfs_util.c
+++ b/nuttx/fs/nfs/nfs_util.c
@@ -120,31 +120,23 @@ void nfs_semgive(struct nfsmount *nmp)
int nfs_checkmount(struct nfsmount *nmp)
{
struct nfsnode *file;
- struct inode *inode;
- struct geometry geo;
- int ret;
- /* If the fs_mounted flag is false, then we have already handled the loss
+ /* If the nm_mounted flag is false, then we have already handled the loss
* of the mount.
*/
- DEBUGASSERT(nmp && nmp->nm_blkdriver);
+ DEBUGASSERT(nmp);
if (nmp->nm_mounted)
{
/* We still think the mount is healthy. Check an see if this is
* still the case
*/
- inode = nmp->nm_blkdriver;
- if (inode->u.i_bops && inode->u.i_bops->geometry)
+#warning "This makes no sense... If you get here, then you know that nmp->nm_mounted and the code will always return OK. Something is wrong."
+ if (nmp->nm_mounted == true)
{
- ret = inode->u.i_bops->geometry(inode, &geo);
- if (ret == OK && geo.geo_available && !geo.geo_mediachanged)
- {
return OK;
- }
}
-
/* If we get here, the mount is NOT healthy */
nmp->nm_mounted = false;